#!/usr/bin/env python3
import logging
from flask import Flask
from flask_restful import Api
import sentry_sdk
from sentry_sdk.integrations.flask import FlaskIntegration
from sentry_sdk.integrations.sqlalchemy import SqlalchemyIntegration
from healthcheck import HealthCheck

from config import *
from db import db
from marshm import ma
from healthchecks import health_database_status

"""
Main Flask RESTful API
"""

__author__ = "@tormakris"
__copyright__ = "Copyright 2020, videON Team"
__module_name__ = "app"
__version__text__ = "1"

if SENTRY_DSN:
    sentry_sdk.init(
        dsn=SENTRY_DSN,
        integrations=[FlaskIntegration(), SqlalchemyIntegration()],
        traces_sample_rate=1.0,
        send_default_pii=True,
        release=RELEASE_ID,
        environment=RELEASEMODE,
        _experiments={"auto_enabling_integrations": True}
    )

app = Flask(__name__)
app.config['SQLALCHEMY_DATABASE_URI'] =\
    f"postgresql://{POSTGRES_USERNAME}:{POSTGRES_PASSWORD}@{POSTGRES_HOSTNAME}:5432/{POSTGRES_DB}"

api = Api(app)
health = HealthCheck(app, "/healthz")
db.init_app(app)
ma.init_app(app)

with app.app_context():
    db.create_all()

formatter = logging.Formatter(
    fmt="%(asctime)s - %(levelname)s - %(module)s - %(message)s"
)

handler = logging.StreamHandler()
handler.setFormatter(formatter)

logger = logging.getLogger(__name__)
logger.setLevel(logging.DEBUG)
logger.addHandler(handler)

# api.add_resource(SampleResource, "/sample")

health.add_check(health_database_status)

if __name__ == "__main__":
    app.run(
        debug=bool(DEBUG),
        host="0.0.0.0",
        port=int(PORT),
    )
